==> lalapps-9.1.0.tar.xz: lalapps-9.1.0/src/lalapps/LALAppsVCSInfoHeader.h <==
/*
 * Copyright (C) 2014, 2016 Karl Wette
 * Copyright (C) 2009-2013 Adam Mercer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

/*
 * LALAppsVCSInfo.h - LALApps VCS Information Header
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALAPPSVCSINFOHEADER_H
#define _LALAPPSVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <LALAppsVCSInfo.h>
#include <config.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information */
#define LALAPPS_VCS_ID "a0875c0521f5515aa66027c4e53b3c0ba35ec1ba"
#define LALAPPS_VCS_DATE "2022-11-3 21:17:17 +0000"
#define LALAPPS_VCS_BRANCH "None"
#define LALAPPS_VCS_TAG "lalapps-v9.1.0"
#define LALAPPS_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALAPPS_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
#define LALAPPS_VCS_CLEAN "CLEAN"
#define LALAPPS_VCS_STATUS "CLEAN: All modifications committed"

#if LALAPPS_VERSION_DEVEL != 0
/* VCS header/library mismatch link check function */
#define LALAPPS_VCS_LINK_CHECK LALAPPS_CLEAN_a0875c0521f5515aa66027c4e53b3c0ba35ec1ba_VCS_HEADER_LIBRARY_MISMATCH
void LALAPPS_VCS_LINK_CHECK(void);
#endif

#ifdef __cplusplus
}
#endif

#endif /* _LALAPPSVCSINFOHEADER_H */

/** \endcond */

==> lalapps-10.0.0.tar.xz: lalapps-10.0.0/src/lalapps/LALAppsVCSInfoHeader.h <==
/*
 * Copyright (C) 2014, 2016 Karl Wette
 * Copyright (C) 2009-2013 Adam Mercer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

/*
 * LALAppsVCSInfo.h - LALApps VCS Information Header
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALAPPSVCSINFOHEADER_H
#define _LALAPPSVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <LALAppsVCSInfo.h>
#include <config.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information */
#define LALAPPS_VCS_ID "7109f31057f3fbce27a4caedff15f45da5b40555"
#define LALAPPS_VCS_DATE "2024-03-22 17:24:33 +0000"
#define LALAPPS_VCS_BRANCH "None"
#define LALAPPS_VCS_TAG "lalapps-v10.0.0"
#define LALAPPS_VCS_AUTHOR "Duncan Macleod <duncan.macleod@ligo.org>"
#define LALAPPS_VCS_COMMITTER "Duncan Macleod <duncan.macleod@ligo.org>"
#define LALAPPS_VCS_CLEAN "CLEAN"
#define LALAPPS_VCS_STATUS "CLEAN: All modifications committed"

#if LALAPPS_VERSION_DEVEL != 0
/* VCS header/library mismatch link check function */
#define LALAPPS_VCS_LINK_CHECK LALAPPS_CLEAN_7109f31057f3fbce27a4caedff15f45da5b40555_VCS_HEADER_LIBRARY_MISMATCH
void LALAPPS_VCS_LINK_CHECK(void);
#endif

#ifdef __cplusplus
}
#endif

#endif /* _LALAPPSVCSINFOHEADER_H */

/** \endcond */
